@@ -87,6 +87,7 @@ local settings = {
   use_esld = true,
   use_redis = false,
   key_prefix = 'arc_keys', -- default hash name
+  reuse_auth_results = false, -- Reuse the existing authentication results
 }
 
 local function parse_arc_header(hdr, target)
@@ -197,7 +198,7 @@ local function arc_callback(task)
     return (e1.i or 0) < (e2.i or 0)
   end)
 
-  rspamd_logger.debugm(N, task, 'got %s arc sections', #cbdata.seals)
+  lua_util.debugm(N, task, 'got %s arc sections', #cbdata.seals)
 
   -- Now check sanity of what we have
   if not arc_validate_seals(task, cbdata.seals, cbdata.sigs,
@@ -210,7 +211,7 @@ local function arc_callback(task)
 
   local function arc_seal_cb(_, res, err, domain)
     cbdata.checked = cbdata.checked + 1
-    rspamd_logger.debugm(N, task, 'checked arc seal: %s(%s), %s processed',
+    lua_util.debugm(N, task, 'checked arc seal: %s(%s), %s processed',
         res, err, cbdata.checked)
 
     if not res then
@@ -233,7 +234,7 @@ local function arc_callback(task)
   end
 
   local function arc_signature_cb(_, res, err, domain)
-    rspamd_logger.debugm(N, task, 'checked arc signature %s: %s(%s), %s processed',
+    lua_util.debugm(N, task, 'checked arc signature %s: %s(%s), %s processed',
       domain, res, err, cbdata.checked)
 
     if not res then
@@ -252,7 +253,7 @@ local function arc_callback(task)
             cbdata.res = 'fail'
             table.insert(cbdata.errors, string.format('sig:%s:%s', sig.d or '', lerr))
             cbdata.checked = cbdata.checked + 1
-            rspamd_logger.debugm(N, task, 'checked arc seal %s: %s(%s), %s processed',
+            lua_util.debugm(N, task, 'checked arc seal %s: %s(%s), %s processed',
               sig.d, ret, lerr, cbdata.checked)
           end
         end, cbdata.seals)
@@ -263,9 +264,50 @@ local function arc_callback(task)
     end
   end
 
-  -- Now we can verify all signatures
+  --[[
+  1.  Collect all ARC Sets currently attached to the message.  If there
+       are none, the Chain Validation Status is "none" and the algorithm
+       stops here.  The maximum number of ARC Sets that can be attached
+       to a message is 50.  If more than the maximum number exist the
+       Chain Validation Status is "fail" and the algorithm stops here.
+       In the following algorithm, the maximum ARC instance value is
+       referred to as "N".
+
+   2.  If the Chain Validation Status of the highest instance value ARC
+       Set is "fail", then the Chain Validation status is "fail" and the
+       algorithm stops here.
+
+   3.  Validate the structure of the Authenticated Received Chain.  A
+       valid ARC has the following conditions:
+
+       1.  Each ARC Set MUST contain exactly one each of the three ARC
+           header fields (AAR, AMS, and AS).
+
+       2.  The instance values of the ARC Sets MUST form a continuous
+           sequence from 1..N with no gaps or repetition.
+
+       3.  The "cv" value for all ARC-Seal header fields must be non-
+           failing.  For instance values > 1, the value must be "pass".
+           For instance value = 1, the value must be "none".
+
+       *  If any of these conditions are not met, the Chain Validation
+          Status is "fail" and the algorithm stops here.
+
+   4.  Validate the AMS with the greatest instance value (most recent).
+       If validation fails, then the Chain Validation Status is "fail"
+       and the algorithm stops here.
+
+   5 - 7. Optional, not implemented
+   8.  Validate each AS beginning with the greatest instance value and
+       proceeding in decreasing order to the AS with the instance value
+       of 1.  If any AS fails to validate, the Chain Validation Status
+       is "fail" and the algorithm stops here.
+   9.  If the algorithm reaches this step, then the Chain Validation
+       Status is "pass", and the algorithm is complete.
+  ]]--
+
   local processed = 0
-  local sig = cbdata.sigs[#cbdata.sigs]
+  local sig = cbdata.sigs[#cbdata.sigs] -- last AMS
   local ret,err = dkim_verify(task, sig.header, arc_signature_cb, 'arc-sign')
 
   if not ret then
@@ -273,7 +315,7 @@ local function arc_callback(task)
     table.insert(cbdata.errors, string.format('sig:%s:%s', sig.d or '', err))
   else
     processed = processed + 1
-    rspamd_logger.debugm(N, task, 'processed arc signature %s[%s]: %s(%s), %s processed',
+    lua_util.debugm(N, task, 'processed arc signature %s[%s]: %s(%s), %s processed',
       sig.d, sig.i, ret, err, cbdata.checked)
   end
 
@@ -301,6 +343,8 @@ end
 local id = rspamd_config:register_symbol({
   name = 'ARC_CALLBACK',
   type = 'callback',
+  group = 'policies',
+  groups = {'arc'},
   callback = arc_callback
 })
 
@@ -311,6 +355,7 @@ rspamd_config:register_symbol({
   type = 'virtual',
   score = -1.0,
   group = 'policies',
+  groups = {'arc'},
 })
 rspamd_config:register_symbol({
   name = arc_symbols['reject'],
@@ -318,6 +363,7 @@ rspamd_config:register_symbol({
   type = 'virtual',
   score = 2.0,
   group = 'policies',
+  groups = {'arc'},
 })
 rspamd_config:register_symbol({
   name = arc_symbols['invalid'],
@@ -325,6 +371,7 @@ rspamd_config:register_symbol({
   type = 'virtual',
   score = 1.0,
   group = 'policies',
+  groups = {'arc'},
 })
 rspamd_config:register_symbol({
   name = arc_symbols['dnsfail'],
@@ -332,6 +379,7 @@ rspamd_config:register_symbol({
   type = 'virtual',
   score = 0.0,
   group = 'policies',
+  groups = {'arc'},
 })
 rspamd_config:register_symbol({
   name = arc_symbols['na'],
@@ -339,6 +387,7 @@ rspamd_config:register_symbol({
   type = 'virtual',
   score = 0.0,
   group = 'policies',
+  groups = {'arc'},
 })
 
 rspamd_config:register_dependency('ARC_CALLBACK', symbols['spf_allow_symbol'])
@@ -348,19 +397,38 @@ local function arc_sign_seal(task, params, header)
   local arc_sigs = task:cache_get('arc-sigs')
   local arc_seals = task:cache_get('arc-seals')
   local arc_auth_results = task:get_header_full('ARC-Authentication-Results') or {}
-  local cur_auth_results = auth_results.gen_auth_results(task) or ''
+  local cur_auth_results
   local privkey
 
   if params.rawkey then
-    privkey = rspamd_rsa_privkey.load_pem(params.rawkey)
+    -- Distinguish between pem and base64
+    if string.match(params.rawkey, '^-----BEGIN') then
+      privkey = rspamd_rsa_privkey.load_pem(params.rawkey)
+    else
+      privkey = rspamd_rsa_privkey.load_base64(params.rawkey)
+    end
   elseif params.key then
     privkey = rspamd_rsa_privkey.load_file(params.key)
   end
 
   if not privkey then
     rspamd_logger.errx(task, 'cannot load private key for signing')
+    return
   end
 
+  if settings.reuse_auth_results then
+    local ar_header = task:get_header('Authentication-Results')
+
+    if ar_header then
+      rspamd_logger.debugm(N, task, 'reuse authentication results header for ARC')
+      cur_auth_results = ar_header
+    else
+      rspamd_logger.debugm(N, task, 'cannot reuse authentication results, header is missing')
+      cur_auth_results = auth_results.gen_auth_results(task) or ''
+    end
+  else
+    cur_auth_results = auth_results.gen_auth_results(task) or ''
+  end
 
   local sha_ctx = hash.create_specific('sha256')
 
@@ -373,18 +441,18 @@ local function arc_sign_seal(task, params, header)
         local s = dkim_canonicalize('ARC-Authentication-Results',
           arc_auth_results[i].value)
         sha_ctx:update(s)
-        rspamd_logger.debugm(N, task, 'update signature with header: %s', s)
+        lua_util.debugm(N, task, 'update signature with header: %s', s)
       end
       if arc_sigs[i] then
         local s = dkim_canonicalize('ARC-Message-Signature',
           arc_sigs[i].raw_header)
         sha_ctx:update(s)
-        rspamd_logger.debugm(N, task, 'update signature with header: %s', s)
+        lua_util.debugm(N, task, 'update signature with header: %s', s)
       end
       if arc_seals[i] then
         local s = dkim_canonicalize('ARC-Seal', arc_seals[i].raw_header)
         sha_ctx:update(s)
-        rspamd_logger.debugm(N, task, 'update signature with header: %s', s)
+        lua_util.debugm(N, task, 'update signature with header: %s', s)
       end
     end
   end
@@ -393,34 +461,44 @@ local function arc_sign_seal(task, params, header)
     'ARC-Message-Signature',
     header)
 
-  cur_auth_results = lua_util.fold_header(task,
-    'ARC-Authentication-Results',
-    cur_auth_results, ';')
-
   cur_auth_results = string.format('i=%d; %s', cur_idx, cur_auth_results)
+  cur_auth_results = lua_util.fold_header(task,
+      'ARC-Authentication-Results',
+      cur_auth_results, ';')
+
   local s = dkim_canonicalize('ARC-Authentication-Results',
     cur_auth_results)
   sha_ctx:update(s)
-  rspamd_logger.debugm(N, task, 'update signature with header: %s', s)
+  lua_util.debugm(N, task, 'update signature with header: %s', s)
   s = dkim_canonicalize('ARC-Message-Signature', header)
   sha_ctx:update(s)
-  rspamd_logger.debugm(N, task, 'update signature with header: %s', s)
+  lua_util.debugm(N, task, 'update signature with header: %s', s)
 
   local cur_arc_seal = string.format('i=%d; s=%s; d=%s; t=%d; a=rsa-sha256; cv=%s; b=',
-      cur_idx, params.selector, params.domain, math.floor(rspamd_util.get_time()), params.arc_cv)
+      cur_idx,
+      params.selector,
+      params.domain,
+      math.floor(rspamd_util.get_time()), params.arc_cv)
   s = string.format('%s:%s', 'arc-seal', cur_arc_seal)
   sha_ctx:update(s)
-  rspamd_logger.debugm(N, task, 'initial update signature with header: %s', s)
+  lua_util.debugm(N, task, 'initial update signature with header: %s', s)
+
+  local nl_type
+  if task:has_flag("milter") then
+    nl_type = "lf"
+  else
+    nl_type = task:get_newlines_type()
+  end
 
   local sig = rspamd_rsa.sign_memory(privkey, sha_ctx:bin())
   cur_arc_seal = string.format('%s%s', cur_arc_seal,
-    sig:base64())
+    sig:base64(70, nl_type))
 
   task:set_milter_reply({
     add_headers = {
-      ['ARC-Authentication-Results'] = {order = 0, value = cur_auth_results},
-      ['ARC-Message-Signature'] = {order = 0, value = header},
-      ['ARC-Seal'] = {order = 0, value = lua_util.fold_header(task,
+      ['ARC-Authentication-Results'] = {order = 1, value = cur_auth_results},
+      ['ARC-Message-Signature'] = {order = 1, value = header},
+      ['ARC-Seal'] = {order = 1, value = lua_util.fold_header(task,
         'ARC-Seal', cur_arc_seal) }
     }
   })
@@ -508,12 +586,24 @@ local function arc_signing_cb(task)
       try_redis_key(p.selector)
     end
   else
-    if (p.key and p.selector) then
-      p.key = lua_util.template(p.key, {domain = p.domain, selector = p.selector})
-      if not rspamd_util.file_exists(p.key) then
-        rspamd_logger.debugm(N, task, 'file %s does not exists', p.key)
-        return false
+    if ((p.key or p.rawkey) and p.selector) then
+      if p.key then
+        p.key = lua_util.template(p.key, {
+          domain = p.domain,
+          selector = p.selector
+        })
+
+        local exists,err = rspamd_util.file_exists(p.key)
+        if not exists then
+          if err and err == 'No such file or directory' then
+            lua_util.debugm(N, task, 'cannot read key from %s: %s', p.key, err)
+          else
+            rspamd_logger.warnx(task, 'cannot read key from %s: %s', p.key, err)
+          end
+          return false
+        end
       end
+
       local dret, hdr = dkim_sign(task, p)
       if dret then
         return arc_sign_seal(task, p, hdr)
@@ -536,10 +626,13 @@ for k,v in pairs(opts) do
     settings[k] = v
   end
 end
-if not (settings.use_redis or settings.path or
-    settings.domain or settings.path_map or settings.selector_map) then
+if not (settings.use_redis or
+    settings.path or
+    settings.domain or
+    settings.path_map or
+    settings.selector_map or
+    settings.use_http_headers) then
   rspamd_logger.infox(rspamd_config, 'mandatory parameters missing, disable arc signing')
-  lua_util.disable_module(N, "fail")
   return
 end
 
@@ -548,14 +641,15 @@ if settings.use_redis then
 
   if not redis_params then
     rspamd_logger.errx(rspamd_config, 'no servers are specified, but module is configured to load keys from redis, disable arc signing')
-    lua_util.disable_module(N, "config")
     return
   end
 end
 
 rspamd_config:register_symbol({
   name = settings['sign_symbol'],
-  callback = arc_signing_cb
+  callback = arc_signing_cb,
+  groups = {"policies", "arc"},
+  score = 0.0,
 })
 
 -- Do not sign unless valid
